@@ -13,19 +13,18 @@ from tests.spark_json_helpers import create_jsonl_files
 
 def test_can_load_patient(spark_session: SparkSession) -> None:
     # Arrange
-    data_dir: Path = Path(__file__).parent.joinpath('./')
+    data_dir: Path = Path(__file__).parent.joinpath("./")
 
-    patient_test_folder: Path = data_dir.joinpath("test_files"
-                                                  ).joinpath("patient.json")
+    patient_test_folder: Path = data_dir.joinpath("test_files").joinpath("patient.json")
 
-    temp_folder = data_dir.joinpath('./temp')
+    temp_folder = data_dir.joinpath("./temp")
     if path.isdir(temp_folder):
         rmtree(temp_folder)
 
     minified_json_path: Path = create_jsonl_files(
         src_file=patient_test_folder,
         dst_folder=temp_folder.joinpath("minified_patient"),
-        dst_file_name="1.json"
+        dst_file_name="1.json",
     )
 
     schema = StructType([])
@@ -36,7 +35,7 @@ def test_can_load_patient(spark_session: SparkSession) -> None:
 
     patient_schema: Union[StructType, DataType] = PatientSchema.get_schema()
     assert isinstance(patient_schema, StructType)
-    result_df: DataFrame = df.sql_ctx.read.schema(patient_schema).json(
+    result_df: DataFrame = df.sparkSession.read.schema(patient_schema).json(
         str(minified_json_path)
     )
 
@@ -44,10 +43,12 @@ def test_can_load_patient(spark_session: SparkSession) -> None:
     result_df.show(truncate=False)
     result_df.createOrReplaceTempView("result_view")
 
-    assert result_df.where("id == 27384972").select("gender"
-                                                    ).collect()[0][0] == "male"
-    assert spark_session.sql(
-        "SELECT identifier[0].type.coding[0].code FROM result_view where id = '27384972'"
-    ).collect()[0][0] == "2"
+    assert result_df.where("id == 27384972").select("gender").collect()[0][0] == "male"
+    assert (
+        spark_session.sql(
+            "SELECT identifier[0].type.coding[0].code FROM result_view where id = '27384972'"
+        ).collect()[0][0]
+        == "2"
+    )
 
     # now make sure we can persist it
